from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware

from app.api.v1.api import api_router
from app.core.config import settings

app = FastAPI(
    title=settings.PROJECT_NAME,
    openapi_url="/openapi.json",
    version=settings.VERSION,
    description=settings.DESCRIPTION,
)

# Set up CORS
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Include API router
app.include_router(api_router, prefix=settings.API_V1_STR)


@app.get("/")
async def root():
    """
    Root endpoint that returns basic application information.
    """
    return {
        "title": settings.PROJECT_NAME,
        "description": settings.DESCRIPTION,
        "version": settings.VERSION,
        "docs_url": "/docs",
        "health_check": "/health",
    }


@app.get("/health", status_code=200)
async def health_check():
    """
    Health check endpoint to verify the service is up and running.
    """
    return {
        "status": "healthy",
        "version": settings.VERSION,
    }